import{C as p,ay as d,c as v,t as l,E as f,m as t,w as a,J as g,I as _,q as V,G as r,H as s,Y as h,u as b,v as B}from"./index-5a44a053.js";import{V as C,a as T}from"./VToolbar-b6309aac.js";import{a as k,V as n}from"./VTabs-c0fa38fb.js";import"./transition-1df78eef.js";import"./index-cc451665.js";import"./VImg-1aa5363e.js";import"./VBtn-bc6fd420.js";import"./forwardRefs-a329760c.js";import"./VProgressCircular-e11c7d5f.js";import"./resizeObserver-115493a9.js";import"./lazy-64d1df8a.js";import"./VSlideGroup-e14de701.js";const w=_("div",{style:{height:"15px"}},null,-1),Y=p({__name:"Settings",setup(y){const i=d(),u=v(()=>{var e,o;return(e=i.currentRoute.value.name)!=null&&e.toString().includes("forecast")?"forecast":(o=i.currentRoute.value.name)!=null&&o.toString().includes("core")?"core":"devices"});return(e,o)=>{const c=V("router-view");return l(),f("div",null,[t(C,{color:"transparent",title:g(h)("bp4")?e.$t("app.settings"):""},{append:a(()=>[t(k,{"model-value":u.value,"align-tabs":"end",height:"100%"},{default:a(()=>[t(n,{value:"devices",to:{name:"devicessettings"}},{default:a(()=>[r(s(e.$t("settings.devices")),1)]),_:1}),t(n,{value:"forecast",to:{name:"forecastsettings"}},{default:a(()=>[r(s(e.$t("settings.forecast")),1)]),_:1}),t(n,{value:"core",to:{name:"coresettings"}},{default:a(()=>[r(s(e.$t("settings.core")),1)]),_:1})]),_:1},8,["model-value"])]),_:1},8,["title"]),t(T),w,t(c,null,{default:a(({Component:m})=>[(l(),b(B(m)))]),_:1})])}}});export{Y as default};
