import{g as t,p as c,s as u,c as r,Q as d}from"./index-5a44a053.js";function l(){const e=t("useScopeId").vnode.scopeId;return{scopeId:e?{[e]:""}:void 0}}const p=c({eager:Boolean},"lazy");function m(o,e){const a=u(!1),s=r(()=>a.value||o.eager||e.value);d(e,()=>a.value=!0);function n(){o.eager||(a.value=!1)}return{isBooted:a,hasContent:s,onAfterLeave:n}}export{m as a,p as m,l as u};
