if(!self.define){let s,e={};const l=(l,r)=>(l=new URL(l+".js",r).href,e[l]||new Promise((e=>{if("document"in self){const s=document.createElement("script");s.src=l,s.onload=e,document.head.appendChild(s)}else s=l,importScripts(l),e()})).then((()=>{let s=e[l];if(!s)throw new Error(`Module ${l} didn’t register its module`);return s})));self.define=(r,i)=>{const n=s||("document"in self?document.currentScript.src:"")||location.href;if(e[n])return;let u={};const a=s=>l(s,n),o={module:{uri:n},exports:u,require:a};e[n]=Promise.all(r.map((s=>o[s]||a(s)))).then((s=>(i(...s),u)))}}define(["./workbox-7cfec069"],(function(s){"use strict";self.addEventListener("message",(s=>{s.data&&"SKIP_WAITING"===s.data.type&&self.skipWaiting()})),s.precacheAndRoute([{url:"assets/_plugin-vue_export-helper-c27b6911.js",revision:null},{url:"assets/CoreConfigs-3df12ade.js",revision:null},{url:"assets/Default-8ccda160.js",revision:null},{url:"assets/Default-9c6e6cd5.css",revision:null},{url:"assets/Devices-41ed5db1.css",revision:null},{url:"assets/Devices-94285b3c.js",revision:null},{url:"assets/EditDeviceConfig-f444fa4d.js",revision:null},{url:"assets/Forecast-c3701681.js",revision:null},{url:"assets/Forecast-e9b564f4.js",revision:null},{url:"assets/forwardRefs-a329760c.js",revision:null},{url:"assets/Home-05591de0.js",revision:null},{url:"assets/index-5a44a053.js",revision:null},{url:"assets/index-b30ab237.js",revision:null},{url:"assets/index-cc451665.js",revision:null},{url:"assets/index-e9a6a998.css",revision:null},{url:"assets/lazy-64d1df8a.js",revision:null},{url:"assets/PowerFlowCard-8cb876ae.js",revision:null},{url:"assets/PowerFlowCard-bf65823d.css",revision:null},{url:"assets/RawData-608c2581.css",revision:null},{url:"assets/RawData-a8ef6ef8.js",revision:null},{url:"assets/resizeObserver-115493a9.js",revision:null},{url:"assets/SessionLog-0951d5c1.css",revision:null},{url:"assets/SessionLog-3eca328d.js",revision:null},{url:"assets/Settings-1f686101.js",revision:null},{url:"assets/Statistics-ef3492d0.js",revision:null},{url:"assets/transition-1df78eef.js",revision:null},{url:"assets/transition-dfb6f675.css",revision:null},{url:"assets/utils-6f3c77d7.js",revision:null},{url:"assets/VBtn-9fb208ad.css",revision:null},{url:"assets/VBtn-bc6fd420.js",revision:null},{url:"assets/VCard-2565a0b7.js",revision:null},{url:"assets/VCard-de6d5ade.css",revision:null},{url:"assets/VImg-1aa5363e.js",revision:null},{url:"assets/VImg-ad18d763.css",revision:null},{url:"assets/VOverlay-168871f7.js",revision:null},{url:"assets/VOverlay-176f17d1.css",revision:null},{url:"assets/VProgressCircular-4a58d9a5.css",revision:null},{url:"assets/VProgressCircular-e11c7d5f.js",revision:null},{url:"assets/VSelect-3b5c15f5.js",revision:null},{url:"assets/VSelect-7aa65c1f.css",revision:null},{url:"assets/VSlideGroup-e14de701.js",revision:null},{url:"assets/VSlideGroup-f07ad3cd.css",revision:null},{url:"assets/VTable-9c8ce44e.css",revision:null},{url:"assets/VTable-f296e4c8.js",revision:null},{url:"assets/VTabs-8212064b.css",revision:null},{url:"assets/VTabs-c0fa38fb.js",revision:null},{url:"assets/VTextField-ce82ae9d.css",revision:null},{url:"assets/VTextField-f153c512.js",revision:null},{url:"assets/VToolbar-1f43fd4d.css",revision:null},{url:"assets/VToolbar-b6309aac.js",revision:null},{url:"assets/workbox-window.prod.es5-c46a1faa.js",revision:null},{url:"index.html",revision:"4cf37346ce959c5d0c87b8bc17a868a7"},{url:"robots.txt",revision:"f77c87f977e0fcce05a6df46c885a129"},{url:"apple-touch-icon.png",revision:"ec84610d7d85b67822bcb8a7f5114354"},{url:"pwa-192x192.png",revision:"568e4ca3a35484f7b1cd02882e9e8ac0"},{url:"pwa-512x512.png",revision:"1e5320b35c3f539c43a9132b901bb0e9"},{url:"manifest.webmanifest",revision:"14575172cc64b2172ce0f6fac9b45006"}],{}),s.cleanupOutdatedCaches(),s.registerRoute(new s.NavigationRoute(s.createHandlerBoundToURL("index.html")))}));
